@@ -16,7 +16,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '1.8.3';
+    $VERSION = '1.8.4';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -85,12 +85,6 @@ sub _pre_171 {
 sub _pre_181 {
     my ( $version, $SETTING ) = @_;
     if ( version->parse($version) < version->parse('1.8.1') ) {
-
-        #        if ( defined $SETTING->{'frontend'}
-        #            and $SETTING->{'frontend'} eq 'libsane-perl' )
-        #        {
-        #            $SETTING->{'frontend'} = 'libimage-sane-perl';
-        #        }
         if ( defined $SETTING->{'default filename'} ) {
             $SETTING->{'default filename'} =~ s/%a/%Da/gsm;
             $SETTING->{'default filename'} =~ s/%t/%Dt/gsm;
@@ -105,6 +99,18 @@ sub _pre_181 {
     return;
 }
 
+sub _pre_184 {
+    my ( $version, $SETTING ) = @_;
+    if ( version->parse($version) < version->parse('1.8.4') ) {
+        if ( defined $SETTING->{'frontend'}
+            and $SETTING->{'frontend'} eq 'libsane-perl' )
+        {
+            $SETTING->{'frontend'} = 'libimage-sane-perl';
+        }
+    }
+    return;
+}
+
 sub read_config {
     my ( $filename, $logger ) = @_;
     my ( %SETTING, $conf );
@@ -172,6 +178,8 @@ sub read_config {
 
     _pre_181( $version, \%SETTING );
 
+    _pre_184( $version, \%SETTING );
+
     $logger->debug( Dumper( \%SETTING ) );
     return %SETTING;
 }
@@ -235,7 +243,7 @@ sub add_defaults {
         'image type'                        => undef,
         device                              => undef,
         'device blacklist'                  => undef,
-        frontend                            => 'libsane-perl',
+        frontend                            => 'libimage-sane-perl',
         'scan prefix'                       => $EMPTY,
         'unpaper on scan'                   => FALSE,
         'unpaper options'                   => undef,
@@ -265,6 +273,7 @@ sub add_defaults {
         'ocr language' => undef,
         'OCR output' =>
           'replace',   # When a page is re-OCRed, replace old text with new text
+        ps_backend              => 'ghostscript',
         user_defined_tools      => ['gimp %i'],
         udt_on_scan             => FALSE,
         current_udt             => undef,
