@@ -31,7 +31,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '1.8.3';
+our $VERSION = '1.8.4';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -308,6 +308,11 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 $widget->{signal} = $widget->signal_connect(
                     changed => sub {
                         my $i = $widget->get_active;
+
+                        # refetch options in case they have changed.
+                        # tested by t/06197_Dialog_Scan_Sane.t
+                        $options = $self->get('available-scan-options');
+                        $opt     = $options->by_name( $opt->{name} );
                         $self->set_option( $opt, $opt->{constraint}[$i] );
                     }
                 );
@@ -358,6 +363,14 @@ sub set_option {
     my ( $self, $option, $val ) = @_;
     if ( not defined $option ) { return }
 
+    if ( $option->{constraint_type} == SANE_CONSTRAINT_RANGE ) {
+        if ( $val < $option->{constraint}{min} ) {
+            $val = $option->{constraint}{min};
+        }
+        elsif ( $val > $option->{constraint}{max} ) {
+            $val = $option->{constraint}{max};
+        }
+    }
     $self->{current_scan_options}->add_backend_option( $option->{name}, $val );
 
     my $signal;
