@@ -25,7 +25,7 @@ Readonly my $MAXVAL_16_BIT  => 2**$_16_BIT - 1;
 my $uuid_object = Data::UUID->new;
 my $EMPTY       = q{};
 
-our $VERSION = '1.8.0';
+our $VERSION = '1.8.4';
 
 my ( $prog_name, $logger, %callback, $_self );
 
@@ -257,7 +257,9 @@ sub scan_pages {
         ),
         started_callback => $options{started_callback},
         running_callback => sub {
-            $options{running_callback}->( $_self->{scan_progress} );
+            if ( defined $options{running_callback} ) {
+                $options{running_callback}->( $_self->{scan_progress} );
+            }
         },
         error_callback    => $options{error_callback},
         finished_callback => sub {
