@@ -34,7 +34,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '1.8.3';
+    $VERSION = '1.8.4';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -98,6 +98,20 @@ sub new {
     }
 
     bless $self, $class;
+
+    # Add units if not defined
+    if ( $suffix{ $options{format} } !~ /^[.]p.m$/xsm ) {
+        my $image = $self->im_object;
+        my $units = $image->Get('units');
+        if ( $units =~ /undefined/xsm ) {
+            $image->Write(
+                units    => 'PixelsPerInch',
+                density  => $self->resolution,
+                filename => $self->{filename}
+            );
+        }
+    }
+
     return $self;
 }
 
@@ -411,22 +425,26 @@ sub string {
 
 sub _boxes2string {
     my ($boxes) = @_;
-    my $string = $EMPTY;
+    my $string  = $EMPTY;
+    my $para    = FALSE;
 
-    # Note y value to be able to put line breaks
-    # at appropriate positions
-    my ( $oldx, $oldy );
     for my $box ( @{$boxes} ) {
         if ( defined $box->{contents} ) {
             $string .= _boxes2string( $box->{contents} );
+            if ( $box->{type} eq 'line' ) { $string .= $SPACE }
+            if ( $box->{type} eq 'para' ) {
+                $string .= "\n\n";
+                $para = TRUE;
+            }
+            else {
+                $para = FALSE;
+            }
         }
-        if ( not defined $box->{text} ) { next }
-        my ( $x1, $y1, $x2, $y2 ) = @{ $box->{bbox} };
-        if ( defined $oldx and $x1 > $oldx ) { $string .= $SPACE }
-        if ( defined $oldy and $y1 > $oldy ) { $string .= "\n" }
-        ( $oldx, $oldy ) = ( $x1, $y1 );
-        $string .= $box->{text};
+        if ( defined $box->{text} ) { $string .= $box->{text} . $SPACE }
     }
+
+    # squashes whitespace at the end of the string
+    if ( not $para ) { $string =~ s/\s+\z//xsm }
     return $string;
 }
 
